function Mesh=mesh_generation(h0)
%create a Mesh using the Matlab command initmesh.
%Mesh.Coordinates and Mesh.Elements are ready for starting the routine
%
%Mesh.Objective indicates the nodes in the objective region
%the nodes on the boundary of the objective region are included
%
%Mesh.ReferenceNodes indicates which nodes are in the
%reference region
%
%Mesh.ReferenceElements indicates which elements are in the
%reference region


freq=10e7;
omega=2*pi*freq;
c0=3e8;             %speed velocity
lambda=c0/freq;
k=omega/c0;

r1=lambda/5;       %radius of the inner circle
L=lambda;          %radius of the outer circle
r_farfield=L/2;    %radius of far field region 


%h0=(L-r1)/12; %maximal meshwidth

Mesh.k=k;
Mesh.r1=r1;
Mesh.L=L;
Mesh.h0=h0;

%Decomposed geometry matrix dl

%external circle
dl(:,1)=[1 L -L 0 0 1 0 0 0 L]';
dl(:,2)=[1 -L L 0 0 1 0 0 0 L]';

%insert scatterer region
dl(:,3)=[1 r1 -r1 0 0 2 1 0 0 r1]';
dl(:,4)=[1 -r1 r1 0 0 2 1 0 0 r1]';

%generate the mesh with maximal meshwidth h0
%[p,e,t]=initmesh(dl);
[p,e,t]=initmesh(dl,'hmax',h0);
%[p,e,t]=refinemesh(dl,p,e,t);
%so we have 4304 nodes
%length(p)

%improve quality
p=jigglemesh(p,e,t);


%see a plot of the whole mesh
% figure;
% axis equal;
% plot(p(1,:),p(2,:),'*');

%plot the different regions (1,2,3)
% region=3;
% rtriangles=find(t(4,:)==region);
% rnodes=unique(t(1:3,rtriangles));
% figure;
% plot(p(1,rnodes),p(2,rnodes),'*');
% xlim([-L L]);
% ylim([-L L]);

%Create Mesh.Coordinates, which is the starting mesh
Mesh.Coordinates=p';

%Create Mesh.Elements
Mesh.Elements=t(1:3,:)';

%Create Mesh.Edges
Mesh = add_Edges(Mesh);
Mesh = add_Edge2Elem(Mesh);

%======================================================================

Mesh.ElemFlag=t(4,:)';

%set flags on the boundary
%   ------ -1 -----------
%   |                   |
%   |                   |
%   |                   |    
%  -1                  -1
%   |                   |
%   |                   |
%   ------ -1 -----------
Loc = get_BdEdges(Mesh);
Mesh.BdFlags = zeros(size(Mesh.Edges,1),1); 
Mesh.BdFlags(Loc)=-1*ones(size(Loc));


%find the boundary edges
Mesh.BdEdges=find(Mesh.BdFlags~=0);
end
