function [M,S,L,UD,F] = Parabolic_LFE(Mesh,t)

  % Initialize constants
  
  nElements = size(Mesh.Elements,1);
  Mhandle = @MASS_LFE;
  Shandle = @STIMA_Lapl_LFE;
  Lhandle = @Source_Function;
  Dhandle = @(x,y) 1;
  
  % Preallocate memory
  
  MI = zeros(9*nElements,1);
  MJ = zeros(9*nElements,1);
  MA = zeros(9*nElements,1);
  
  SI = zeros(9*nElements,1);
  SJ = zeros(9*nElements,1);
  SA = zeros(9*nElements,1);
  
  % Check for element flags
  
  if(isfield(Mesh,'ElemFlag')),
    flags = Mesh.ElemFlag; 
  else
    flags = zeros(nElements,1);
  end
  
     Mesh.ElemFlag = flags;

  
  % Assemble element contributions
  
  loc = 1:9;
  for i = 1:nElements
    
    % Extract vertices of current element
    
    idx = Mesh.Elements(i,:);
    Vertices = Mesh.Coordinates(idx,:);
      
    % Compute element contributions
    
    Mloc = Mhandle(Vertices,flags(i));
    Sloc = Shandle(Vertices,flags(i));
   
    % Add contributions to stiffness matrix
    
    MI(loc) = set_Rows(idx,3);
    MJ(loc) = set_Cols(idx,3);
    MA(loc) = Mloc(:);
    
    SI(loc) = set_Rows(idx,3);
    SJ(loc) = set_Cols(idx,3);
    SA(loc) = Sloc(:);
    
    loc = loc+9;
    
  end
  
  % Assign output arguments
    M = sparse(MI,MJ,MA);    
    
    S = sparse(SI,SJ,SA); 
    
   % L = Source_Load(Mesh,P7O6,Lhandle,t);
    L = assemLoad_LFE(Mesh,P7O6,Lhandle,t);
    
    [UD,F] = assemDir_LFE(Mesh,-1,Dhandle);
